@@ -2,7 +2,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
 
 #include <gtk/gtk.h>
 
@@ -87,7 +86,9 @@ read_line (FILE *stream, GString *str)
 {
   int n_read = 0;
   
+#ifndef G_OS_WIN32
   flockfile (stream);
+#endif
 
   g_string_truncate (str, 0);
   
@@ -95,7 +96,11 @@ read_line (FILE *stream, GString *str)
     {
       int c;
       
+#ifndef G_OS_WIN32
       c = getc_unlocked (stream);
+#else
+      c = getc (stream);
+#endif
 
       if (c == EOF)
 	goto done;
@@ -107,7 +112,11 @@ read_line (FILE *stream, GString *str)
 	case '\r':
 	case '\n':
 	  {
+#ifndef G_OS_WIN32
 	    int next_c = getc_unlocked (stream);
+#else
+	    int next_c = getc (stream);
+#endif
 	    
 	    if (!(next_c == EOF ||
 		  (c == '\r' && next_c == '\n') ||
@@ -123,7 +132,9 @@ read_line (FILE *stream, GString *str)
 
  done:
 
+#ifndef G_OS_WIN32
   funlockfile (stream);
+#endif
 
   return n_read > 0;
 }
@@ -448,7 +459,7 @@ load_file (const gchar *filename)
 	{
 	case 0:
 	  /* Reading title */
-	  while (*p == '/' || *p == '*' || isspace (*p))
+	  while (*p == '/' || *p == '*' || g_ascii_isspace (*p))
 	    p++;
 	  r = p;
 	  while (*r != '/' && strlen (r))
@@ -456,7 +467,7 @@ load_file (const gchar *filename)
 	  if (strlen (r) > 0)
 	    p = r + 1;
 	  q = p + strlen (p);
-	  while (q > p && isspace (*(q - 1)))
+	  while (q > p && g_ascii_isspace (*(q - 1)))
 	    q--;
 
 	  if (q > p)
@@ -480,7 +491,7 @@ load_file (const gchar *filename)
 	    
 	case 1:
 	  /* Reading body of info section */
-	  while (isspace (*p))
+	  while (g_ascii_isspace (*p))
 	    p++;
 	  if (*p == '*' && *(p + 1) == '/')
 	    {
@@ -491,11 +502,11 @@ load_file (const gchar *filename)
 	    {
 	      int len;
 	      
-	      while (*p == '*' || isspace (*p))
+	      while (*p == '*' || g_ascii_isspace (*p))
 		p++;
 
 	      len = strlen (p);
-	      while (isspace (*(p + len - 1)))
+	      while (g_ascii_isspace (*(p + len - 1)))
 		len--;
 	      
 	      if (len > 0)
@@ -517,7 +528,7 @@ load_file (const gchar *filename)
 
 	case 2:
 	  /* Skipping blank lines */
-	  while (isspace (*p))
+	  while (g_ascii_isspace (*p))
 	    p++;
 	  if (*p)
 	    {
@@ -661,7 +672,8 @@ create_tree (void)
   Demo *d = testgtk_demos;
 
   model = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_BOOLEAN);
-  tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+  tree_view = gtk_tree_view_new ();
+  gtk_tree_view_set_model (GTK_TREE_VIEW (tree_view), GTK_TREE_MODEL (model));
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree_view));
 
   gtk_tree_selection_set_mode (GTK_TREE_SELECTION (selection),
@@ -727,7 +739,6 @@ create_tree (void)
   g_signal_connect (tree_view, "row_activated", G_CALLBACK (row_activated_cb), model);
 
   gtk_tree_view_expand_all (GTK_TREE_VIEW (tree_view));
-
   return tree_view;
 }
 
