@@ -207,7 +207,7 @@ gtk_socket_new (void)
 /**
  * gtk_socket_steal:
  * @socket: a #GtkSocket
- * @wid: the XID of an existing toplevel window.
+ * @wid: the window ID of an existing toplevel window.
  * 
  * Reparents a pre-existing toplevel window into a #GtkSocket. This is
  * meant to embed clients that do not know about embedding into a
@@ -232,14 +232,14 @@ gtk_socket_steal (GtkSocket *socket, GdkNativeWindow wid)
 /**
  * gtk_socket_add_id:
  * @socket: a #GtkSocket
- * @id: the XID of a client participating in the XEMBED protocol.
+ * @window_id: the window ID of a client participating in the XEMBED protocol.
  *
  * Adds an XEMBED client, such as a #GtkPlug, to the #GtkSocket.  The
  * client may be in the same process or in a different process. 
  * 
  * To embed a #GtkPlug in a #GtkSocket, you can either create the
- * #GtkPlug with gtk_plug_new (0), call gtk_plug_get_id() to get the
- * window ID of the plug, and then pass that to the
+ * #GtkPlug with <literal>gtk_plug_new (0)</literal>, call 
+ * gtk_plug_get_id() to get the window ID of the plug, and then pass that to the
  * gtk_socket_add_id(), or you can call gtk_socket_get_id() to get the
  * window ID for the socket, and call gtk_plug_new() passing in that
  * ID.
@@ -248,7 +248,7 @@ gtk_socket_steal (GtkSocket *socket, GdkNativeWindow wid)
  *  before you can make this call.
  **/
 void           
-gtk_socket_add_id (GtkSocket *socket, GdkNativeWindow id)
+gtk_socket_add_id (GtkSocket *socket, GdkNativeWindow window_id)
 {
   g_return_if_fail (GTK_IS_SOCKET (socket));
   g_return_if_fail (GTK_WIDGET_ANCHORED (socket));
@@ -256,7 +256,7 @@ gtk_socket_add_id (GtkSocket *socket, GdkNativeWindow id)
   if (!GTK_WIDGET_REALIZED (socket))
     gtk_widget_realize (GTK_WIDGET (socket));
 
-  gtk_socket_add_window (socket, id, TRUE);
+  gtk_socket_add_window (socket, window_id, TRUE);
 }
 
 /**
@@ -265,9 +265,10 @@ gtk_socket_add_id (GtkSocket *socket, GdkNativeWindow id)
  * 
  * Gets the window ID of a #GtkSocket widget, which can then
  * be used to create a client embedded inside the socket, for
- * instance with gtk_socket_new (id). The #GtkSocket must
- * have already be added into a toplevel window before you
- * can make this call.
+ * instance with gtk_plug_new(). 
+ *
+ * The #GtkSocket must have already be added into a toplevel window 
+ * before you can make this call.
  * 
  * Return value: the window ID for the socket
  **/
@@ -611,7 +612,7 @@ toplevel_key_press_handler (GtkWidget   *toplevel,
 
 #endif
 
-static void
+static gboolean
 toplevel_focus_in_handler (GtkWidget     *toplevel,
 			   GdkEventFocus *event,
 			   GtkSocket     *socket)
@@ -624,15 +625,19 @@ toplevel_focus_in_handler (GtkWidget     *toplevel,
   if (GTK_WIDGET_VISIBLE (toplevel))
     send_xembed_message (socket, XEMBED_WINDOW_ACTIVATE, 0, 0, 0,
 			 gtk_get_current_event_time ()); /* Will be GDK_CURRENT_TIME */
+
+  return FALSE;
 }
 
-static void
+static gboolean
 toplevel_focus_out_handler (GtkWidget     *toplevel,
 			    GdkEventFocus *event,
 			    GtkSocket     *socket)
 {
   send_xembed_message (socket, XEMBED_WINDOW_DEACTIVATE, 0, 0, 0,
 		       gtk_get_current_event_time ()); /* Will be GDK_CURRENT_TIME */
+
+  return FALSE;
 }
 
 static void
@@ -676,9 +681,12 @@ static void
 gtk_socket_grab_notify (GtkWidget *widget,
 			gboolean   was_grabbed)
 {
-  send_xembed_message (GTK_SOCKET (widget),
-		       was_grabbed ? XEMBED_MODALITY_OFF : XEMBED_MODALITY_ON,
-		       0, 0, 0, gtk_get_current_event_time ());
+  GtkSocket *socket = GTK_SOCKET (widget);
+
+  if (!socket->same_app)
+    send_xembed_message (GTK_SOCKET (widget),
+			 was_grabbed ? XEMBED_MODALITY_OFF : XEMBED_MODALITY_ON,
+			 0, 0, 0, gtk_get_current_event_time ());
 }
 
 static gboolean
@@ -687,7 +695,7 @@ gtk_socket_key_press_event (GtkWidget   *widget,
 {
   GtkSocket *socket = GTK_SOCKET (widget);
   
-  if (socket->plug_window)
+  if (GTK_WIDGET_HAS_FOCUS (socket) && socket->plug_window && !socket->plug_widget)
     {
       XEvent xevent;
       
