@@ -100,6 +100,8 @@ struct _GtkTextView
    * last "invalidate" signal from the layout
    */
   guint onscreen_validated : 1;
+
+  guint mouse_cursor_obscured : 1;
   
   GtkTextWindow *text_window;
   GtkTextWindow *left_window;
@@ -168,6 +170,15 @@ struct _GtkTextViewClass
                         GtkMovementStep step,
                         gint            count,
                         gboolean        extend_selection);
+
+  /* FIXME should be deprecated in favor of adding GTK_MOVEMENT_HORIZONTAL_PAGES
+   * or something in GTK 2.2, was put in to avoid adding enum values during
+   * the freeze.
+   */
+  void (* page_horizontally) (GtkTextView *text_view,
+                              gint         count,
+                              gboolean     extend_selection);
+  
   /* move the "anchor" (what Emacs calls the mark) to the cursor position */
   void (* set_anchor)  (GtkTextView    *text_view);
 
@@ -185,6 +196,11 @@ struct _GtkTextViewClass
   /* overwrite */
   void (* toggle_overwrite) (GtkTextView *text_view);
 
+  /* propagates to GtkWindow move_focus */
+  void (* move_focus)       (GtkTextView     *text_view,
+                             GtkDirectionType direction);  
+  
+  
   GtkFunction pad1;
   GtkFunction pad2;
   GtkFunction pad3;
